@@ -1,7 +1,7 @@
 package Log::ger;
 
 our $DATE = '2017-07-14'; # DATE
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 #IFUNBUILT
 # use strict;
@@ -54,6 +54,9 @@ my $default_null_routines = [
         [$sub0, "log_$_", $Levels{$_}, 'log_sub'],
             [$Levels{$_} > $Current_Level ? $sub0 : $sub1, "log_is_$_",
              $Levels{$_}, 'is_sub'],
+        [$sub0, $_, $Levels{$_}, 'log_method'],
+            [$Levels{$_} > $Current_Level ? $sub0 : $sub1, "is_$_",
+             $Levels{$_}, 'is_method'],
          } keys %Levels),
 ];
 
@@ -159,7 +162,7 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
